@@ -130,7 +130,7 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0038   => "自身のノードの タイムラインID のほうが相手のノードの タイムラインID よりも大きくなっています ([0] > [1])\n",
     SLAVESTART_MS0040   => "相手のノードに WAL ファイルが存在しません: [0]\n",
     SLAVESTART_MS0041   => "自身のノードの XLOG の位置のほうが相手のノードの XLOG の位置よりも進んでいます ([0] > [1])\n",
-    SLAVESTART_MS0042   => "相手のノードに最新のタイムライン履歴ファイルが存在しません: [0]\n",
+    SLAVESTART_MS0042   => "相手のノードにタイムライン履歴ファイルが存在しません\n",
     SLAVESTART_MS0043   => "相手のノードのタイムラインIDに対応するタイムライン履歴ファイル \"[0]\" に自身のノードのタイムラインIDを通った履歴が残っていません\n",
     SLAVESTART_MS0044   => "相手ノードは自身のノードのLSNより以前に昇格しています\n",
     SLAVESTART_MS0045   => "自身のノードをベースバックアップから再構築してください\n",
@@ -174,6 +174,7 @@ _SLAVESTART_USAGE_
     SLAVESTART_MS0081   => "Master のアーカイブディレクトリに Master の現在の LSN よりも進んだ WAL ファイルが存在します\n",
     SLAVESTART_MS0082   => "--optionsまたはPG_BASEBACKUP_opt(pg-rex_tools.conf)の設定は無視します\n",
     SLAVESTART_MS0083   => "pg_wal の WAL ファイルの状態が不適切です。このまま Slave を起動するとアーカイブログが欠損するためスクリプトを終了します\n",
+    SLAVESTART_MS0087   => "タイムラインID [0] に対応するタイムライン履歴ファイルが相手のノードに存在しません: [1]\n",
     SLAVESTART_MS0099   => "内部エラー\n",
 
     STOP_USAGE  => <<_STOP_USAGE_,
@@ -390,6 +391,7 @@ _SWITCHOVER_USAGE_
     COMMON_MS0049       => "自身のノードで [0] が稼働しています。起動処理を中止します。\n",
     COMMON_MS0050       => "ロックファイル([0])の作成に失敗しました。\n",
     COMMON_MS0051       => "ロックファイル([0])の削除に失敗しました。: [1]\n",
+    COMMON_MS0052       => "[0] はIPv4の形式ではありません。\n",
 };
 
 1;
